local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

function PWBInfo:OnInitialize()
	self.db = Protwarbar.db.profile.PWBInfo
	self.Vengeance_name = GetSpellInfo(93098)
	self.barrier = 0

	PWBInfo:BuildGui()

	self:RegisterMessage("PWB_ABILITIES_LOADED")
	self:RegisterMessage("PWB_PROFILE_CHANGED")
	self:RegisterMessage("PWB_REFRESH_CONFIG")
	self:RegisterMessage("PWB_UPDATE_VISIBILITY")
	self:RegisterMessage("PWB_UPDATE_HANDLERS")
end

function PWBInfo:OnEnable()
	PWBInfo:UpdateStats()
	PWBInfo:PWB_UPDATE_HANDLERS()
end

function PWBInfo:PWB_UPDATE_HANDLERS()

	self:UnregisterEvent("UNIT_POWER_FREQUENT")
	self:UnregisterEvent("UNIT_ATTACK_POWER")
	self:UnregisterEvent("UNIT_STATS")

	if self.db.enabled and Protwarbar.db.profile.enabled then
		self:RegisterEvent("UNIT_POWER_FREQUENT")
		self:RegisterEvent("UNIT_ATTACK_POWER")
		self:RegisterEvent("UNIT_STATS")
	end
end

function PWBInfo:PWB_PROFILE_CHANGED()
	self.db = Protwarbar.db.profile.PWBInfo
end

function PWBInfo:PWB_ABILITIES_LOADED()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("PWBInfo", PWBInfo:CreateOptions());
	Protwarbar.AceConfig:AddToBlizOptions("PWBInfo", L["Information"], "Protwarbar");
end

function PWBInfo:PWB_REFRESH_CONFIG()
	self:RefreshConfig()
end

function PWBInfo:PWB_UPDATE_VISIBILITY()
	self:UpdateVisiblity()
end

function PWBInfo:UNIT_POWER_FREQUENT(eventName, unit, powerType)
	if (unit == "player") then
		PWBInfo:Update(UnitPower("player"))
	end
end

function PWBInfo:UNIT_ATTACK_POWER(event, unit)
	if (unit == "player") then
		PWBInfo:UpdateStats()
	end
end

function PWBInfo:UNIT_STATS(event, unit)
	if (unit == "player") then
		PWBInfo:UpdateStats()
	end
end

function PWBInfo:UpdateStats()
		local _, stamina, _, _ = UnitStat("player", 3); -- get stamina
		local _, strength, _, _ = UnitStat("player", 1); -- get strength
		local baseAP, posBuffAP, negBuffAP = UnitAttackPower("player"); --AP value

		local attackPowerSide = (baseAP + posBuffAP + negBuffAP - strength * 2) * 1.8;
		self.barrier = max(attackPowerSide, stamina * 2.5)
end

function PWBInfo:RefreshConfig()
	self:UpdateStyling()
	self:UpdateVisiblity()
end

function PWBInfo:Update(power)
	local shieldBarrierText = ""

	if self.db.shieldBarrier.enabled then
		if power > 19 then

			if power > 59 then
				shieldBarrierText = string.format("%.1fK", self.barrier / 1000)
			else
				shieldBarrierText = string.format("%.1fK", self.barrier * power / 60 / 1000)
			end

		end
	end

	local ventext = ""

	if self.db.vengeance.enabled then
		local n,_,_,_,_,_,_,_,_,_,id,_,_,val1,val2,val3 = UnitAura("player", self.Vengeance_name, nil, "HELPFUL");

		if n then
			local vengeance = val2 or 0

			if vengeance > 0 then
				ventext = string.format("%.1fK", vengeance / 1000)
			end
		end
	end

	local seperator = ""
	if self.db.vengeance.enabled and self.db.shieldBarrier.enabled then
		seperator = self.db.seperator
	end
	VengeanceText:SetText(ventext .. seperator .. shieldBarrierText)
end